@@ -40,7 +40,8 @@ REQUESTS_KWARGS: dict[str, Any] = {
 
 
 class GetPixivToken(object):
-    def __init__(self, headless: bool,
+    def __init__(self,
+                 headless: Optional[bool] = False,
                  user: Optional[str] = None,
                  pass_: Optional[str] = None) -> None:
         self.headless, self.user, self. pass_ = headless, user, pass_
@@ -169,6 +170,8 @@ class GetPixivToken(object):
         options.add_argument('--proxy-server="direct://"')
         options.add_argument('--proxy-bypass-list=*')
         options.add_argument('--start-maximized')
+        options.add_argument('--no-sandbox')
+        options.add_argument('--disable-dev-shm-usage')
         options.add_argument('--user-agent=' + USER_AGENT)
         options.add_experimental_option(
             "excludeSwitches", ["enable-automation"])
